@@ -364,14 +364,14 @@ on_captured_event (ClutterActor      *stage,
   if (!priv->in_drag)
     return CLUTTER_EVENT_PROPAGATE;
 
-  if (clutter_event_get_device (event) != priv->device)
+  if (clutter_event_get_device (event) != priv->device ||
+      clutter_event_get_event_sequence (event) != priv->sequence)
     return CLUTTER_EVENT_PROPAGATE;
 
   switch (clutter_event_type (event))
     {
     case CLUTTER_TOUCH_UPDATE:
-      if (clutter_event_get_event_sequence (event) == priv->sequence)
-        emit_drag_motion (action, actor, event);
+      emit_drag_motion (action, actor, event);
       break;
 
     case CLUTTER_MOTION:
@@ -391,8 +391,7 @@ on_captured_event (ClutterActor      *stage,
 
     case CLUTTER_TOUCH_END:
     case CLUTTER_TOUCH_CANCEL:
-      if (clutter_event_get_event_sequence (event) == priv->sequence)
-        emit_drag_end (action, actor, event);
+      emit_drag_end (action, actor, event);
       break;
 
     case CLUTTER_BUTTON_RELEASE:
@@ -427,6 +426,8 @@ on_drag_begin (ClutterActor      *actor,
   switch (clutter_event_type (event))
     {
     case CLUTTER_BUTTON_PRESS:
+      if (priv->sequence != NULL)
+        return CLUTTER_EVENT_PROPAGATE;
       if (clutter_event_get_button (event) != CLUTTER_BUTTON_PRIMARY)
         return CLUTTER_EVENT_PROPAGATE;
       break;
@@ -1141,14 +1142,18 @@ clutter_drag_action_set_drag_handle (ClutterDragAction *action,
 
   priv->transformed_press_x = priv->press_x;
   priv->transformed_press_y = priv->press_y;
-  clutter_actor_transform_stage_point (handle, priv->press_x, priv->press_y,
-                                       &priv->transformed_press_x,
-                                       &priv->transformed_press_y);
 
   if (priv->drag_handle != NULL)
-    g_signal_connect (priv->drag_handle, "destroy",
-                      G_CALLBACK (on_drag_handle_destroy),
-                      action);
+    {
+      clutter_actor_transform_stage_point (priv->drag_handle,
+                                           priv->press_x,
+                                           priv->press_y,
+					   &priv->transformed_press_x,
+					   &priv->transformed_press_y);
+      g_signal_connect (priv->drag_handle, "destroy",
+			G_CALLBACK (on_drag_handle_destroy),
+			action);
+    }
 
   g_object_notify_by_pspec (G_OBJECT (action), drag_props[PROP_DRAG_HANDLE]);
 }
