@@ -269,7 +269,7 @@ clutter_transition_class_init (ClutterTransitionClass *klass)
    *
    * Whether the #ClutterTransition should be automatically detached
    * from the #ClutterTransition:animatable instance whenever the
-   * #ClutterTimeline::completed signal is emitted.
+   * #ClutterTimeline::stopped signal is emitted.
    *
    * The #ClutterTransition:remove-on-complete property takes into
    * account the value of the #ClutterTimeline:repeat-count property,
@@ -318,6 +318,9 @@ clutter_transition_set_interval (ClutterTransition *transition,
 
   priv = transition->priv;
 
+  if (priv->interval == interval)
+    return;
+
   g_clear_object (&priv->interval);
 
   if (interval != NULL)
@@ -469,10 +472,9 @@ clutter_transition_set_value (ClutterTransition *transition,
   if (priv->interval == NULL)
     {
       priv->interval = clutter_interval_new_with_values (G_VALUE_TYPE (value),
-                                                         value,
-                                                         value);
+                                                         NULL,
+                                                         NULL);
       g_object_ref_sink (priv->interval);
-      return;
     }
 
   interval_type = clutter_interval_get_value_type (priv->interval);
