@@ -145,6 +145,7 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/actor", actor_basic_layout);
   TEST_CONFORM_SIMPLE ("/actor", actor_margin_layout);
   TEST_CONFORM_SIMPLE ("/actor", actor_offscreen_redirect);
+  TEST_CONFORM_SIMPLE ("/actor", actor_offscreen_limit_max_size);
   TEST_CONFORM_SIMPLE ("/actor", actor_shader_effect);
 
   TEST_CONFORM_SIMPLE ("/actor/iter", actor_iter_traverse_children);
@@ -164,6 +165,8 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/actor/invariants", default_stage);
   TEST_CONFORM_SIMPLE ("/actor/invariants", actor_pivot_transformation);
 
+  TEST_CONFORM_SIMPLE ("/actor/meta", actor_meta_clear);
+
   TEST_CONFORM_SIMPLE ("/actor/opacity", opacity_label);
   TEST_CONFORM_SIMPLE ("/actor/opacity", opacity_rectangle);
   TEST_CONFORM_SIMPLE ("/actor/opacity", opacity_paint);
@@ -187,7 +190,6 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/rectangle", rectangle_set_color);
 
   TEST_CONFORM_SIMPLE ("/texture", texture_pick_with_alpha);
-  TEST_CONFORM_SIMPLE ("/texture", texture_fbo);
   TEST_CONFORM_SIMPLE ("/texture/cairo", texture_cairo);
 
   TEST_CONFORM_SIMPLE ("/interval", interval_initial_state);
@@ -252,7 +254,7 @@ main (int argc, char **argv)
 
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_npot_texture);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_multitexture);
-  TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_mipmaps);
+  TEST_CONFORM_TODO ("/cogl/texture", test_cogl_texture_mipmaps);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_rectangle);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_pixmap_x11);
   TEST_CONFORM_SIMPLE ("/cogl/texture", test_cogl_texture_get_set_data);
